cosinnus.forms package
======================

Submodules
----------

cosinnus.forms.attached_object module
-------------------------------------

.. automodule:: cosinnus.forms.attached_object
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.forms.group module
---------------------------

.. automodule:: cosinnus.forms.group
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.forms.hierarchy module
-------------------------------

.. automodule:: cosinnus.forms.hierarchy
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.forms.profile module
-----------------------------

.. automodule:: cosinnus.forms.profile
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.forms.tagged module
----------------------------

.. automodule:: cosinnus.forms.tagged
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.forms.user module
--------------------------

.. automodule:: cosinnus.forms.user
    :members:
    :undoc-members:
    :show-inheritance:

cosinnus.forms.widgets module
-----------------------------

.. automodule:: cosinnus.forms.widgets
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cosinnus.forms
    :members:
    :undoc-members:
    :show-inheritance:
